package cn.com.infosec.mobile.android.xlog;

import android.support.annotation.Keep;
import cn.com.infosec.mobile.android.xlog.formatter.border.BorderFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.json.JsonFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.object.ObjectFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.throwable.ThrowableFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.xml.XmlFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.stacktrace.StackTraceFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.thread.ThreadFormatter;
import cn.com.infosec.mobile.android.xlog.interceptor.Interceptor;
import cn.com.infosec.mobile.android.xlog.internal.DefaultsFactory;
import cn.com.infosec.mobile.android.xlog.internal.Platform;
import cn.com.infosec.mobile.android.xlog.internal.util.StackTraceUtil;
import cn.com.infosec.mobile.android.xlog.printer.Printer;
import cn.com.infosec.mobile.android.xlog.printer.PrinterSet;

@Keep
public class XLog {
   private static Logger sLogger;
   static LogConfiguration sLogConfiguration;
   static Printer sPrinter;
   static boolean sIsInitialized;

   private XLog() {
   }

   public static void init() {
      init((new LogConfiguration.Builder()).build(), DefaultsFactory.createPrinter());
   }

   public static void init(int logLevel) {
      init((new LogConfiguration.Builder()).logLevel(logLevel).build(), DefaultsFactory.createPrinter());
   }

   /** @deprecated */
   @Deprecated
   public static void init(int logLevel, LogConfiguration logConfiguration) {
      init((new LogConfiguration.Builder(logConfiguration)).logLevel(logLevel).build());
   }

   public static void init(LogConfiguration logConfiguration) {
      LogConfiguration var10000 = logConfiguration;
      Printer[] logConfiguration1;
      (logConfiguration1 = new Printer[1])[0] = DefaultsFactory.createPrinter();
      init(var10000, logConfiguration1);
   }

   public static void init(Printer... printers) {
      init((new LogConfiguration.Builder()).build(), printers);
   }

   public static void init(int logLevel, Printer... printers) {
      init((new LogConfiguration.Builder()).logLevel(logLevel).build(), printers);
   }

   /** @deprecated */
   @Deprecated
   public static void init(int logLevel, LogConfiguration logConfiguration, Printer... printers) {
      init((new LogConfiguration.Builder(logConfiguration)).logLevel(logLevel).build(), printers);
   }

   public static void init(LogConfiguration logConfiguration, Printer... printers) {
      if (sIsInitialized) {
         Platform.get().warn("XLog is already initialized, do not initialize again");
      }

      sIsInitialized = true;
      if (logConfiguration != null) {
         sLogConfiguration = logConfiguration;
         PrinterSet logConfiguration1;
         PrinterSet var10000 = logConfiguration1 = new PrinterSet;
         var10000.<init>(printers);
         sPrinter = var10000;
         sLogger = new Logger(sLogConfiguration, logConfiguration1);
      } else {
         throw new IllegalArgumentException("Please specify a LogConfiguration");
      }
   }

   static void assertInitialization() {
      if (!sIsInitialized) {
         throw new IllegalStateException("Do you forget to initialize XLog?");
      }
   }

   public static Logger.Builder logLevel(int logLevel) {
      return (new Logger.Builder()).logLevel(logLevel);
   }

   public static Logger.Builder tag(String tag) {
      return (new Logger.Builder()).tag(tag);
   }

   /** @deprecated */
   @Deprecated
   public static Logger.Builder t() {
      return enableThreadInfo();
   }

   public static Logger.Builder enableThreadInfo() {
      return (new Logger.Builder()).enableThreadInfo();
   }

   /** @deprecated */
   @Deprecated
   public static Logger.Builder nt() {
      return disableThreadInfo();
   }

   public static Logger.Builder disableThreadInfo() {
      return (new Logger.Builder()).disableThreadInfo();
   }

   /** @deprecated */
   @Deprecated
   public static Logger.Builder st(int depth) {
      return enableStackTrace(depth);
   }

   public static Logger.Builder enableStackTrace(int depth) {
      return (new Logger.Builder()).enableStackTrace(depth);
   }

   /** @deprecated */
   @Deprecated
   public static Logger.Builder st(String stackTraceOrigin, int depth) {
      return enableStackTrace(stackTraceOrigin, depth);
   }

   public static Logger.Builder enableStackTrace(String stackTraceOrigin, int depth) {
      return (new Logger.Builder()).enableStackTrace(stackTraceOrigin, depth);
   }

   /** @deprecated */
   @Deprecated
   public static Logger.Builder nst() {
      return disableStackTrace();
   }

   public static Logger.Builder disableStackTrace() {
      return (new Logger.Builder()).disableStackTrace();
   }

   /** @deprecated */
   @Deprecated
   public static Logger.Builder b() {
      return enableBorder();
   }

   public static Logger.Builder enableBorder() {
      return (new Logger.Builder()).enableBorder();
   }

   /** @deprecated */
   @Deprecated
   public static Logger.Builder nb() {
      return disableBorder();
   }

   public static Logger.Builder disableBorder() {
      return (new Logger.Builder()).disableBorder();
   }

   public static Logger.Builder jsonFormatter(JsonFormatter jsonFormatter) {
      return (new Logger.Builder()).jsonFormatter(jsonFormatter);
   }

   public static Logger.Builder xmlFormatter(XmlFormatter xmlFormatter) {
      return (new Logger.Builder()).xmlFormatter(xmlFormatter);
   }

   public static Logger.Builder throwableFormatter(ThrowableFormatter throwableFormatter) {
      return (new Logger.Builder()).throwableFormatter(throwableFormatter);
   }

   public static Logger.Builder threadFormatter(ThreadFormatter threadFormatter) {
      return (new Logger.Builder()).threadFormatter(threadFormatter);
   }

   public static Logger.Builder stackTraceFormatter(StackTraceFormatter stackTraceFormatter) {
      return (new Logger.Builder()).stackTraceFormatter(stackTraceFormatter);
   }

   public static Logger.Builder borderFormatter(BorderFormatter borderFormatter) {
      return (new Logger.Builder()).borderFormatter(borderFormatter);
   }

   public static <T> Logger.Builder addObjectFormatter(Class<T> objectClass, ObjectFormatter<? super T> objectFormatter) {
      return (new Logger.Builder()).addObjectFormatter(objectClass, objectFormatter);
   }

   public static Logger.Builder addInterceptor(Interceptor interceptor) {
      return (new Logger.Builder()).addInterceptor(interceptor);
   }

   public static Logger.Builder printers(Printer... printers) {
      return (new Logger.Builder()).printers(printers);
   }

   public static void v(Object object) {
      assertInitialization();
      sLogger.v(object);
   }

   public static void v(Object[] array) {
      assertInitialization();
      sLogger.v(array);
   }

   public static void v(String format, Object... args) {
      assertInitialization();
      sLogger.v(format, args);
   }

   public static void v(String msg) {
      assertInitialization();
      sLogger.v(msg);
   }

   public static void v(String msg, Throwable tr) {
      assertInitialization();
      sLogger.v(msg, tr);
   }

   public static void d(Object object) {
      assertInitialization();
      sLogger.d(object);
   }

   public static void d(Object[] array) {
      assertInitialization();
      sLogger.d(array);
   }

   public static void d(String format, Object... args) {
      assertInitialization();
      sLogger.d(format, args);
   }

   public static void d(String msg) {
      assertInitialization();
      sLogger.d(msg);
   }

   public static void d(String msg, Throwable tr) {
      assertInitialization();
      sLogger.d(msg, tr);
   }

   public static void i(Object object) {
      assertInitialization();
      sLogger.i(object);
   }

   public static void i(Object[] array) {
      assertInitialization();
      sLogger.i(array);
   }

   public static void i(String format, Object... args) {
      assertInitialization();
      sLogger.i(format, args);
   }

   public static void i(String msg) {
      assertInitialization();
      sLogger.i(msg);
   }

   public static void i(String msg, Throwable tr) {
      assertInitialization();
      sLogger.i(msg, tr);
   }

   public static void w(Object object) {
      assertInitialization();
      sLogger.w(object);
   }

   public static void w(Object[] array) {
      assertInitialization();
      sLogger.w(array);
   }

   public static void w(String format, Object... args) {
      assertInitialization();
      sLogger.w(format, args);
   }

   public static void w(String msg) {
      assertInitialization();
      sLogger.w(msg);
   }

   public static void w(String msg, Throwable tr) {
      assertInitialization();
      sLogger.w(msg, tr);
   }

   public static void e(Object object) {
      assertInitialization();
      sLogger.e(object);
   }

   public static void e(Object[] array) {
      assertInitialization();
      sLogger.e(array);
   }

   public static void e(String format, Object... args) {
      assertInitialization();
      sLogger.e(format, args);
   }

   public static void e(String msg) {
      assertInitialization();
      sLogger.e(msg);
   }

   public static void e(String msg, Throwable tr) {
      assertInitialization();
      sLogger.e(msg, tr);
   }

   public static void log(int logLevel, Object object) {
      assertInitialization();
      sLogger.log(logLevel, object);
   }

   public static void log(int logLevel, Object[] array) {
      assertInitialization();
      sLogger.log(logLevel, array);
   }

   public static void log(int logLevel, String format, Object... args) {
      assertInitialization();
      sLogger.log(logLevel, format, args);
   }

   public static void log(int logLevel, String msg) {
      assertInitialization();
      sLogger.log(logLevel, msg);
   }

   public static void log(int logLevel, String msg, Throwable tr) {
      assertInitialization();
      sLogger.log(logLevel, msg, tr);
   }

   public static void json(String json) {
      assertInitialization();
      sLogger.json(json);
   }

   public static void xml(String xml) {
      assertInitialization();
      sLogger.xml(xml);
   }

   /** @deprecated */
   public static class Log {
      /** @deprecated */
      public static void v(String tag, String msg) {
         XLog.tag(tag).build().v(msg);
      }

      /** @deprecated */
      public static void v(String tag, String msg, Throwable tr) {
         XLog.tag(tag).build().v(msg, tr);
      }

      /** @deprecated */
      public static void d(String tag, String msg) {
         XLog.tag(tag).build().d(msg);
      }

      /** @deprecated */
      public static void d(String tag, String msg, Throwable tr) {
         XLog.tag(tag).build().d(msg, tr);
      }

      /** @deprecated */
      public static void i(String tag, String msg) {
         XLog.tag(tag).build().i(msg);
      }

      /** @deprecated */
      public static void i(String tag, String msg, Throwable tr) {
         XLog.tag(tag).build().i(msg, tr);
      }

      /** @deprecated */
      public static void w(String tag, String msg) {
         XLog.tag(tag).build().w(msg);
      }

      /** @deprecated */
      public static void w(String tag, String msg, Throwable tr) {
         XLog.tag(tag).build().w(msg, tr);
      }

      /** @deprecated */
      public static void w(String tag, Throwable tr) {
         XLog.tag(tag).build().w("", tr);
      }

      /** @deprecated */
      public static void e(String tag, String msg) {
         XLog.tag(tag).build().e(msg);
      }

      /** @deprecated */
      public static void e(String tag, String msg, Throwable tr) {
         XLog.tag(tag).build().e(msg, tr);
      }

      /** @deprecated */
      public static void wtf(String tag, String msg) {
         e(tag, msg);
      }

      /** @deprecated */
      public static void wtf(String tag, Throwable tr) {
         wtf(tag, "", tr);
      }

      /** @deprecated */
      public static void wtf(String tag, String msg, Throwable tr) {
         e(tag, msg, tr);
      }

      /** @deprecated */
      public static void println(int logLevel, String tag, String msg) {
         XLog.tag(tag).build().println(logLevel, msg);
      }

      /** @deprecated */
      public static boolean isLoggable(String tag, int level) {
         return XLog.sLogConfiguration.isLoggable(level);
      }

      /** @deprecated */
      public static String getStackTraceString(Throwable tr) {
         return StackTraceUtil.getStackTraceString(tr);
      }
   }
}
